@@ -7,9 +7,7 @@ User = get_user_model()
 
 
 class LoginForm(forms.Form):
-    email = forms.EmailField(
-        widget=forms.EmailInput(attrs={'autofocus': 'autofocus'})
-    )
+    email = forms.EmailField()
 
     def clean_email(self):
         email = self.cleaned_data['email']
