@@ -10,7 +10,11 @@ LOGIN_SENT_TEMPLATE_NAME = getattr(settings, 'MAGICLINK_LOGIN_SENT_TEMPLATE_NAME
 
 # If this setting is set to False a user account will be created the first time
 # a user requests a login link.
-REQUIRE_SIGNUP = True
+REQUIRE_SIGNUP = getattr(settings, 'MAGICLINK_REQUIRE_SIGNUP', True)
+if not isinstance(REQUIRE_SIGNUP, bool):
+    raise ImproperlyConfigured('"MAGICLINK_REQUIRE_SIGNUP" must be a boolean')
+SIGNUP_LOGIN_REDIRECT = getattr(settings, 'MAGICLINK_SIGNUP_LOGIN_REDIRECT', '')   # NOQA: E501
+
 SIGNUP_TEMPLATE_NAME = getattr(settings, 'MAGICLINK_SIGNUP_TEMPLATE_NAME', 'magiclink/signup.html')   # NOQA: E501
 
 try:
@@ -23,10 +27,6 @@ else:
                    'sussptable to brute force attacks')
         warnings.warn(warning, RuntimeWarning)
 
-EMAIL_VERIFY = getattr(settings, 'MAGICLINK_EMAIL_VERIFY', True)
-if not isinstance(EMAIL_VERIFY, bool):
-    raise ImproperlyConfigured('"MAGICLINK_EMAIL_VERIFY" must be a boolean')
-
 try:
     # In seconds
     AUTH_TIMEOUT = int(getattr(settings, 'MAGICLINK_AUTH_TIMEOUT', 300))
@@ -42,11 +42,6 @@ EMAIL_IGNORE_CASE = getattr(settings, 'MAGICLINK_EMAIL_IGNORE_CASE', True)
 if not isinstance(EMAIL_IGNORE_CASE, bool):
     raise ImproperlyConfigured('"MAGICLINK_EMAIL_IGNORE_CASE" must be a boolean')  # NOQA: E501
 
-REQUIRE_SIGNUP = getattr(settings, 'MAGICLINK_REQUIRE_SIGNUP', True)
-if not isinstance(REQUIRE_SIGNUP, bool):
-    raise ImproperlyConfigured('"MAGICLINK_REQUIRE_SIGNUP" must be a boolean')
-SIGNUP_LOGIN_REDIRECT = getattr(settings, 'MAGICLINK_SIGNUP_LOGIN_REDIRECT', '')   # NOQA: E501
-
 EMAIL_AS_USERNAME = getattr(settings, 'MAGICLINK_EMAIL_AS_USERNAME', True)
 if not isinstance(EMAIL_AS_USERNAME, bool):
     raise ImproperlyConfigured('"MAGICLINK_EMAIL_AS_USERNAME" must be a boolean')  # NOQA: E501
@@ -59,9 +54,9 @@ ALLOW_STAFF_LOGIN = getattr(settings, 'MAGICLINK_ALLOW_STAFF_LOGIN', True)
 if not isinstance(ALLOW_STAFF_LOGIN, bool):
     raise ImproperlyConfigured('"MAGICLINK_ALLOW_STAFF_LOGIN" must be a boolean')  # NOQA: E501
 
-VERIFY_WITH_EMAIL = getattr(settings, 'MAGICLINK_VERIFY_WITH_EMAIL', True)
-if not isinstance(VERIFY_WITH_EMAIL, bool):
-    raise ImproperlyConfigured('"MAGICLINK_VERIFY_WITH_EMAIL" must be a boolean')  # NOQA: E501
+VERIFY_INCLUDE_EMAIL = getattr(settings, 'MAGICLINK_VERIFY_INCLUDE_EMAIL', True)  # NOQA: E501
+if not isinstance(VERIFY_INCLUDE_EMAIL, bool):
+    raise ImproperlyConfigured('"MAGICLINK_VERIFY_INCLUDE_EMAIL" must be a boolean')  # NOQA: E501
 
 REQUIRE_SAME_BROWSER = getattr(settings, 'MAGICLINK_REQUIRE_SAME_BROWSER', True)  # NOQA: E501
 if not isinstance(REQUIRE_SAME_BROWSER, bool):
